archie

Ishikawa Ichiro (ichiro@ccsr.u-tokyo.ac.jp)
Tue, 28 Jun 1994 17:36:21 +0900


Is there any plan to include archie.el in efs package?
The following is my patch to Jack Repenning(jackr@dblues.wpd.sgi.com)'s
archie.el(version 3.0,17-May-1993).

--- /usr/local/lib/mule/lisp-local/archie.el	Wed Aug 18 14:58:29 1993
+++ /home/acc1/ichiro/lib/mule2/lisp/archie.el	Tue Jun 28 17:29:41 1994
@@ -112,6 +112,8 @@
 ;; 17-May-1993|3.0|~/interfaces/archie.el.Z|
 ;;
 
+(require 'efs-auto)
+
 ;; Customization variables
 
 (defvar archie-program "archie"
@@ -429,7 +431,6 @@
               (message "%s converting." am)
               (goto-char (point-min))
               (archie-order-results)
-              (require 'ange-ftp)
               (if archie-do-convert-to-dired (convert-archie-to-dired))
               (setq buffer-read-only t)
               (message "%s done." am)))
@@ -462,9 +463,9 @@
 
 (defun convert-archie-to-dired ()
   "Convert a buffer containing output in 'archie -l' format into a Dired-mode
-buffer in which the usual Dired commands can be used, via ange-ftp."
+buffer in which the usual Dired commands can be used, via efs."
   (interactive)
-  (if (not (fboundp 'ange-ftp-get-user)) (load "ange-ftp"))
+  (if (not (fboundp 'efs-get-user)) (load "efs"))
   (let (lines b s date size host file type year)
     (setq year (substring (current-time-string) -4))
     (setq lines (count-lines (point-min) (point-max)))
@@ -525,7 +526,7 @@
                           (concat " " (substring date 8 10) ":"
 				  (substring date 10 12))
                         (concat "  " (substring date 0 4)))
                       ;; file name, in Ange-FTP format
                       (archie-get-user-prefix host) host ":" file
                       ?\n))
             (delete-region b (point))
@@ -553,11 +554,11 @@
 
 (defun archie-get-user-prefix (host)
   "Return a suitable string to affix to the archie filename for this HOST."
-  (if (not (fboundp 'ange-ftp-get-user)) (load "ange-ftp"))
+  (if (not (fboundp 'efs-get-user)) (load "efs"))
   (let ((prefix (concat " /" archie-anonymous-ftp-username "@")))
-    (if (or (not ange-ftp-default-user)
-            (stringp ange-ftp-default-user))
-        (let ((user (ange-ftp-get-user host)))
+    (if (or (not efs-default-user)
+            (stringp efs-default-user))
+        (let ((user (efs-get-user host)))
           (if (or (string-equal user "anonymous")
                   (string-equal user "ftp"))
               (setq prefix " /"))))
@@ -525,7 +526,7 @@
 				  (substring date 10 12))
                         (concat "  " (substring date 0 4)))
-                      ;; file name, in Ange-FTP format
+                      ;; file name, in Efs format
                       (archie-get-user-prefix host) host ":" file
                       ?\n))
--
Ichiro Ishikawa 
Center for Climate System Research, 
Univ. Tokyo, JAPAN
Email: ichiro@ccsr.u-tokyo.ac.jp